summary refs log tree commit diff
path: root/gnu/packages/tex.scm
diff options
context:
space:
mode:
authorMaxim Cournoyer <maxim.cournoyer@gmail.com>2021-01-14 00:23:38 -0500
committerMaxim Cournoyer <maxim.cournoyer@gmail.com>2021-01-29 13:35:47 -0500
commit82f5f6b14c9a23c201b06048ea24e698a7dc2276 (patch)
treec980a0bf011972ef662b31f7d911549028d861aa /gnu/packages/tex.scm
parent57fad03c4ff8c40505ec0416a21a103f4d2ad83e (diff)
downloadguix-82f5f6b14c9a23c201b06048ea24e698a7dc2276.tar.gz
gnu: Replace all uses of texlive-union by texlive-updmap.cfg.
* doc/build.scm (pdf-manual) Replace texlive-union by texlive-updmap.cfg.
* gnu/packages/algebra.scm (pari-gp): Likewise.
* gnu/packages/bioinformatics.scm (discrover, velvet): Likewise.
* gnu/packages/chez.scm (chez-scheme, chez-web, chez-sockets): Likewise.
* gnu/packages/docbook.scm (dblatex): Likewise.
* gnu/packages/emacs-xyz.scm (emacs-auctex): Likewise.
* gnu/packages/engineering.scm (fastcap): Likewise.
* gnu/packages/guile-xyz.scm (emacsy, guile-cv): Likewise.
* gnu/packages/lisp.scm (sbcl): Likewise.
* gnu/packages/maths.scm (octave, hypre): Likewise.
* gnu/packages/music.scm (lilypond): Likewise.
* gnu/packages/plotutils.scm (asymptote): Likewise.
* gnu/packages/python-xyz.scm (python-numpy-documentation)
(python-matplotlib-documentation, python-ipython-documentation)
(python-pypandoc): Likewise.
* gnu/packages/radio.scm (gnuradio, libosmo-dsp): Likewise.
* gnu/packages/scheme.scm (mit-scheme): Likewise.
* gnu/packages/statistics.scm (r-with-tests): Likewise.
* gnu/packages/tex.scm (simple-texlive-package)
(texlive-xmltex, texlive-tiny, texlive-jadetex, teximpatient, lyx): Likewise.
Diffstat (limited to 'gnu/packages/tex.scm')
-rw-r--r--gnu/packages/tex.scm10
1 files changed, 5 insertions, 5 deletions
diff --git a/gnu/packages/tex.scm b/gnu/packages/tex.scm
index 3d7aed30c7..fa5a0c6404 100644
--- a/gnu/packages/tex.scm
+++ b/gnu/packages/tex.scm
@@ -3009,7 +3009,7 @@ tables.")
                    (symlink pdftex (string-append out "/bin/pdfxmltex"))
                    #t)))))))
       (propagated-inputs
        ;; The following fonts are propagated as a texlive-union as the font
        ;; maps need to be recreated for the fonts to be usable.  They are
        ;; required by xmltex through mlnames.sty and unicode.sty.
        `(("texlive" ,(texlive-updmap.cfg
@@ -3843,7 +3843,7 @@ ones.")
 ;; For use in package definitions only
 (define-public texlive-tiny
   (package
-    (inherit (texlive-union))
+    (inherit (texlive-updmap.cfg))
     (name "texlive-tiny")
     (description "This is a very limited subset of the TeX Live distribution.
 It includes little more than the required set of LaTeX packages.")))
@@ -5803,7 +5803,7 @@ Simple Young tableaux.
                    (symlink pdftex (string-append out "/bin/pdfjadetex"))
                    #t)))))))
       (propagated-inputs
        ;; Propagate the texlive-union input used by xmltex, which provides the
        ;; required fonts for its use.
        `(("texlive-xmltex" ,texlive-xmltex)
          ("texlive-kpathsea" ,texlive-kpathsea))) ;for fmtutil.cnf template
@@ -6685,7 +6685,7 @@ develop documents with LaTeX, in a single application.")
              (delete-file "book.pdf")
              #t)))))
     (native-inputs
-     `(("texlive" ,(texlive-union (list texlive-amsfonts
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-fonts-adobe-palatino
                                         texlive-fonts-adobe-zapfding
                                         texlive-knuth-lib
@@ -6755,7 +6755,7 @@ and Karl Berry.")
        ("qtsvg" ,qtsvg)
        ("zlib" ,zlib)))
     (propagated-inputs
-     `(("texlive" ,(texlive-union (list texlive-fonts-ec)))))
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-fonts-ec)))))
     (native-inputs
      `(("python" ,python)
        ("pkg-config" ,pkg-config)))
@@ -3009,7 +3009,7 @@ tables.")
                    #t)))))))
       (propagated-inputs
-       ;; The following fonts are propagated as a texlive-union as the font
+       ;; The following fonts are propagated as a texlive-updmap.cfg as the font
        ;; maps need to be recreated for the fonts to be usable.  They are
        ;; required by xmltex through mlnames.sty and unicode.sty.
@@ -5803,7 +5803,7 @@ Simple Young tableaux.
                    #t)))))))
       (propagated-inputs
-       ;; Propagate the texlive-union input used by xmltex, which provides the
+       ;; Propagate the texlive-updmap.cfg input used by xmltex, which provides the
        ;; required fonts for its use.
        `(("texlive-xmltex" ,texlive-xmltex)